@@ -234,8 +234,8 @@ class Executor:
             logger.debug(f'instances: {self._instances}')
             logger.debug(f'mapping: {dict(self._jobs_to_instances)}')
 
-            still_running = [f'{jid}:{str(iids).replace(" ", "")}' for jid, iids in self._jobs_to_instances.items()]
-            logger.info(f'Running: {", ".join(still_running)}')
+            still_running = [f'{jid}:{str(iids).replace(" ", "")}' for jid, iids in self._jobs_to_instances.items() if iids]
+            logger.info(f'Currently running: {", ".join(still_running)}')
 
             logger.debug('cleaned up')
 
